@@ -8,6 +8,7 @@
 
 from __future__ import unicode_literals, absolute_import, print_function, division
 
+import re
 import sopel.test_tools
 import functools
 
@@ -250,10 +251,10 @@ def intent(*intent_list):
 
 def rate(user=0, channel=0, server=0):
     """Decorate a function to limit how often it can be triggered on a per-user
-    basis, in a channel, or across the server (bot). A value of zero means no 
+    basis, in a channel, or across the server (bot). A value of zero means no
     limit. If a function is given a rate of 20, that function may only be used
     once every 20 seconds in the scope corresponding to the parameter.
-    Users on the admin list in Sopel’s configuration are exempted from rate 
+    Users on the admin list in Sopel’s configuration are exempted from rate
     limits.
 
     Rate-limited functions that use scheduled future commands should import
@@ -372,6 +373,25 @@ def require_owner(message=None):
     return actual_decorator
 
 
+def url(url_rule):
+    """Decorate a function to handle URLs.
+
+    This decorator takes a regex string that will be matched against URLs in a
+    message. The function it decorates, in addition to the bot and trigger,
+    must take a third argument ``match``, which is the regular expression match
+    of the url. This should be used rather than the matching in trigger, in
+    order to support e.g. the ``.title`` command.
+    """
+    def actual_decorator(function):
+        @functools.wraps(function)
+        def helper(bot, trigger, match=None):
+            match = match or trigger
+            return function(bot, trigger, match)
+        helper.url_regex = re.compile(url_rule)
+        return helper
+    return actual_decorator
+
+
 class example(object):
     """Decorate a function with an example.
 
