@@ -1,12 +1,7 @@
 # coding=utf-8
-"""
-search.py - Sopel Web Search Module
-Copyright 2008-9, Sean B. Palmer, inamidst.com
-Copyright 2012, Edward Powell, embolalia.net
-Licensed under the Eiffel Forum License 2.
-
-http://sopel.chat
-"""
+# Copyright 2008-9, Sean B. Palmer, inamidst.com
+# Copyright 2012, Elsie Powell, embolalia.com
+# Licensed under the Eiffel Forum License 2.
 from __future__ import unicode_literals, absolute_import, print_function, division
 
 import re
@@ -19,7 +14,8 @@ if sys.version_info.major < 3:
     from urllib import quote_plus
 else:
     from urllib.parse import quote_plus
-    
+
+
 def formatnumber(n):
     """Format a number with beautiful commas."""
     parts = list(str(n))
@@ -37,15 +33,15 @@ def bing_search(query, lang='en-GB'):
     if m:
         return m.group(1)
 
-r_duck = re.compile(r'nofollow" class="[^"]+" href="(.*?)">')
+r_duck = re.compile(r'nofollow" class="[^"]+" href="(?!https?:\/\/r\.search\.yahoo)(.*?)">')
 
 
 def duck_search(query):
     query = query.replace('!', '')
     uri = 'http://duckduckgo.com/html/?q=%s&kl=uk-en' % query
     bytes = web.get(uri)
-    if 'web-result"' in bytes:  # filter out the adds on top of the page
-        bytes = bytes.split('web-result"')[1]
+    if 'web-result' in bytes:  # filter out the adds on top of the page
+        bytes = bytes.split('web-result')[1]
     m = r_duck.search(bytes)
     if m:
         return web.decode(m.group(1))
@@ -57,11 +53,11 @@ google_search = duck_search
 def duck_api(query):
     if '!bang' in query.lower():
         return 'https://duckduckgo.com/bang.html'
-    
+
     # This fixes issue #885 (https://github.com/sopel-irc/sopel/issues/885)
-    # It seems that duckduckgo api redirects to its Instant answer API html page 
+    # It seems that duckduckgo api redirects to its Instant answer API html page
     # if the query constains special charactares that aren't urlencoded.
-    # So in order to always get a JSON response back the query is urlencoded 
+    # So in order to always get a JSON response back the query is urlencoded
     query = quote_plus(query)
     uri = 'http://api.duckduckgo.com/?q=%s&format=json&no_html=1&no_redirect=1' % query
     results = json.loads(web.get(uri))
@@ -107,7 +103,7 @@ def search(bot, trigger):
     du = duck_search(query) or '-'
 
     if bu == du:
-        result = '%s (b, d)' % gu
+        result = '%s (b, d)' % bu
     else:
         if len(bu) > 150:
             bu = '(extremely long link)'
